@@ -24,7 +24,7 @@
 
 */
 
-#include "../../config.h"
+#include "config.h"
 #include "global.h"
 #include "utils.h"
 #include "utils_no_qt.h"
