@@ -193,7 +193,7 @@ void IPTCfgParser::start_table() {
 			// clear current table
 			importer->current_table = "";
 			}
-			importer->current_table = LT(0)->getText();
+			importer->registerTable(LT(0)->getText());
 			*dbg << "TABLE " << LT(0)->getText() << std::endl;
 			
 #line 200 "IPTCfgParser.cpp"
